@@ -82,8 +82,8 @@ def make_release(version=None):
         _log(msg)
         base.svn_commit(msg)
     finally:
-        shutil.rmtree(rep)
-
+        shutil.rmtree(rep, ignore_errors=True)
+        
 def parse_url(url):
     """return base_url, cfg::
 
@@ -135,7 +135,7 @@ def diff_releases(old=None, new=None, result=None):
 
     if result is None:
         result = '%s-to-%s.tgz' % (root_old_name, root_new_name)
-        working_dir = os.path.realpath(os.curdir)
+        working_dir = os.path.realpath(os.getcwd())
     else:
         working_dir, result = os.path.split(result)
         working_dir = os.path.realpath(working_dir)
@@ -167,11 +167,11 @@ def diff_releases(old=None, new=None, result=None):
     os.rename(join(topdir, result), join(working_dir, result))
     _log('Diff done.')
 
-def archive_contents(archive, location, exclude=None):
+def archive_contents(archive, location, exclude=None, source=True):
     """generates the tarball"""
     location = os.path.realpath(location)
     # we want a relative storage
-    old_dir = os.curdir    
+    old_dir = os.getcwd()    
     os.chdir(location)
     dirname, name = os.path.split(location)
     tar = base.TarFile.open(join(dirname, archive), 'w:gz')
@@ -202,6 +202,8 @@ def archive_contents(archive, location, exclude=None):
             for filename in filenames:
                 if filename in ('.installed.cfg', '.Python'):
                     continue
+                if source and filename.split('.')[-1] in ('pyc', 'pyo'):
+                    continue
                 path = join(root, filename)
                 arcname = path.replace(location, '.')
                 tar.add(path, arcname, False)
@@ -230,13 +232,18 @@ def get_option(filename, section, option):
 
 def _python():
     """returns python bin"""
-    
-    possible_locations = (join('bin', 'python*'),
-                          join('Scripts', 'python*'))
-    for location in possible_locations:
-        for found in glob(location):
-            if os.path.exists(found):
-                return found
+    if sys.platform == 'win32':
+        found = glob(join('Scripts', 'python*'))
+        target = join('Scripts', 'python.exe')
+    else:
+        found = glob(join('bin', 'python*'))
+        target = join('bin', 'python')
+
+    if target in found:
+        return target
+    for found in found:
+        if os.path.exists(found):
+            return found
     return 'python'
 
 def _set_dynlibs(root):
@@ -252,6 +259,36 @@ def _set_dynlibs(root):
         libfilename = os.path.split(lib)[-1]
         shutil.copy(lib, join(libs_dir, libfilename))
 
+def _make_python(location='.'):
+    # let's generate a virtualenv python
+    # to make sure we don't loose eggs
+    old = sys.argv
+    try:
+        sys.argv = ['project_deploy', '--no-site-packages', location]
+        from virtualenv import main
+        try:
+            def after_install(options, home_dir):
+                """Creates a `python` script"""
+                installed = _python()
+                if sys.platform == 'win32':
+                    wanted = 'python.exe'
+                else:
+                    wanted = 'python'
+                if os.path.split(installed)[-1] != wanted:
+                    dirname = os.path.dirname(installed)
+                    shutil.copyfile(installed, os.path.join(dirname, 
+                                                            wanted)) 
+            main()
+        except OSError:
+            # file must exist
+            pass 
+    finally:
+        sys.argv = old
+    if sys.platform == 'win32':
+        return os.path.join(location, 'Scripts', 'python.exe')
+    else:
+        return os.path.join(location, 'bin', 'python')
+
 def deploy_release(path=None, target=None, archiving='full'):
     """deploy a release in-place"""
     print 'Checking python version ...'
@@ -295,14 +332,8 @@ def deploy_release(path=None, target=None, archiving='full'):
 
     # let's generate a virtualenv python
     # to make sure we don't loose eggs
-    old = sys.argv
-    try:
-        sys.argv = ['project_deploy', '--no-site-packages', '.']
-        from virtualenv import main
-        main()
-    finally:
-        sys.argv = old
-        
+    _make_python()
+       
     # create the libs folder if needed
     if sys.platform == 'win32':
         _set_dynlibs(root)
