@@ -25,7 +25,7 @@ from zc.buildout.testing import rmdir
 
 from iw.releaser.project import (archive_contents, _python, 
                                  diff_releases, _set_dynlibs, 
-                                 _extract_url)
+                                 _extract_url,  _make_python)
 from iw.releaser import testing
 from iw.releaser import base
 
@@ -48,8 +48,43 @@ class ProjectTest(unittest.TestCase):
 
     def tearDown(self):
         testing.releaserTearDown(self)
-         
-    def test_archiving(self):         
+     
+    def test_light_archiving(self):
+        
+        location = join(os.path.dirname(__file__), 'tarball')
+        tarfile_ = join(os.path.dirname(__file__), 'pack.tgz')
+
+        # light archiving
+        archive_contents('pack.tgz', location, source=True) 
+        import tarfile
+        tar = tarfile.open(tarfile_, "r:gz")
+        try:
+            elements = [tarinfo.name for tarinfo in tar
+                        if not os.path.split(tarinfo.name)[-1].startswith('.')]
+        finally:
+            tar.close()
+
+        for el in ['downloads/file.pyc', 'file2.pyc', 'file3.pyo']:
+            self.assert_(el not in elements)
+
+        os.remove(tarfile_)
+
+        # complete archiving
+        archive_contents('pack.tgz', location, source=False) 
+        import tarfile
+        tar = tarfile.open(tarfile_, "r:gz")
+        try:
+            elements = [tarinfo.name for tarinfo in tar
+                        if not os.path.split(tarinfo.name)[-1].startswith('.')]
+        finally:
+            tar.close()
+
+        for el in ['downloads/file.pyc', 'file2.pyc', 'file3.pyo']:
+            self.assert_(el in elements)
+
+        os.remove(tarfile_)
+    
+    def test_archiving(self): 
         location = join(os.path.dirname(__file__), 'tarball')
         #previous = self.svn_root
         tarfile_ = join(os.path.dirname(__file__), 'pack.tgz')
@@ -78,12 +113,16 @@ class ProjectTest(unittest.TestCase):
         try:
             os.mkdir(join(test_bin, 'bin'))
             os.mkdir(join(test_bin, 'Scripts'))
-            
-            for place in (('bin', 'python'), 
-                          ('bin', 'python2.4'),
-                          ('bin', 'python2.4.3'),
-                          ('Scripts', 'python')):
+            linux =  (('bin', 'python'), 
+                      ('bin', 'python2.4'),
+                      ('bin', 'python2.4.3'))
+            windows = (('Scripts', 'python.exe'),)
+            if sys.platform == 'win32': 
+                places = windows
+            else:
+                places = linux
 
+            for place in places:
                 f = open(join(test_bin, place[0], place[1]), 'w')
                 f.write('#')
                 f.close()
@@ -150,6 +189,15 @@ class ProjectTest(unittest.TestCase):
         prot, path = _extract_url('svn://svn.ingeniweb.com/pack')
         self.assertEquals(prot, 'svn://')
         self.assertEquals(path, ['svn.ingeniweb.com', 'pack'])
+    
+    def test_make_python(self):
+        python = _make_python(curdir)
+        try:
+            self.assert_(os.path.exists(python)) 
+        finally:
+            if os.path.exists(python):
+                dir_ = os.path.dirname(python)
+                shutil.rmtree(dir_)
 
 def test_suite():
     """returns the test suite"""
